@@ -1,5 +1,5 @@
 from .imports import *
-import pprint
+from . import _utils
 
 def get_grades(soup: BeautifulSoup, mode="type"):
     """Get a list of grades from a BeautifulSoup object
@@ -109,6 +109,16 @@ def _karakterer(self, mode):
 
 def karakterer(self):
     karaktererDict = {
+        "oversigt": {
+            "karakterblad": {
+                "gennemsnit": None,
+                "karakterer": None,
+            },
+            "protokollinjer": {
+                "gennemsnit": None,
+                "karakterer": None,
+            },
+        },
         "karakterblad": [],
         "karakternoter": [],
         "protokollinjer": [],
@@ -122,17 +132,49 @@ def karakterer(self):
         raise Exception("lectio-cookie udløbet")
     oversigtSoup = BeautifulSoup(resp.text, "html.parser")
 
+    # VÆGTNING
+    vægtning = {}
+    for row in oversigtSoup.find("div", {"id": "s_m_Content_Content_karakterView_LectioDetailIsland1_pa"}).find_all("tr")[1:]:
+        vægtning[row.find_all("td")[1].text.replace("SAM", "Samlet vurdering")] = row.find("div", {"class": "textCenter"}).get("title").split("\n")[2].split(": ")[1] # Håber det er standardized på alle skoler
+
+    _terminer = oversigtSoup.find("select", {"name": "s$m$ChooseTerm$term"})
+    selected = _terminer.find("option", {"selected": "selected"}).get("value")
+    terminer = dict([[termin.get("value"), termin.text] for termin in _terminer.find_all("option")])
+    del terminer[selected]
+
+    payload = _utils.generatePayload(oversigtSoup, "s$m$ChooseTerm$term")
+    payload["__EVENTARGUMENT"] = ""
+    payload["__LASTFOCUS"] = ""
+    payload["m$searchinputfield"] = ""
+    payload["LectioPostbackId"] = ""
+
+    for termin in terminer:
+        payload = _utils.generatePayload(oversigtSoup, "s$m$ChooseTerm$term")
+        payload["__EVENTARGUMENT"] = ""
+        payload["__LASTFOCUS"] = ""
+        payload["m$searchinputfield"] = ""
+        payload["LectioPostbackId"] = ""
+        payload["s$m$ChooseTerm$term"] = str(termin)
+        resp = self.session.post(url, data="&".join([f"{urllib.parse.quote(key)}={urllib.parse.quote(value)}" for key, value in payload.items()]), allow_redirects=False)
+        oversigtSoup = BeautifulSoup(resp.text, "html.parser")
+        for row in oversigtSoup.find("div", {"id": "s_m_Content_Content_karakterView_LectioDetailIsland1_pa"}).find_all("tr")[1:]:
+            vægtning[row.find_all("td")[1].text.replace("SAM", "Samlet vurdering")] = row.find("div", {"class": "textCenter"}).get("title").split("\n")[2].split(": ")[1] # Håber det er standardized på alle skoler
+
+    payload = _utils.generatePayload(oversigtSoup, "s$m$ChooseTerm$term")
+    payload["__EVENTARGUMENT"] = ""
+    payload["__LASTFOCUS"] = ""
+    payload["m$searchinputfield"] = ""
+    payload["LectioPostbackId"] = ""
+    payload["s$m$ChooseTerm$term"] = str(selected)
+    self.session.post(url, data="&".join([f"{urllib.parse.quote(key)}={urllib.parse.quote(value)}" for key, value in payload.items()]), allow_redirects=False)
+    
+
     url = f"https://www.lectio.dk/lectio/{self.skoleId}/grades/grade_karakterblad.aspx?elevid={self.elevId}"
     resp = self.session.get(url)
     if resp.url != url:
         raise Exception("lectio-cookie udløbet")
     karakterbladSoup = BeautifulSoup(resp.text, "html.parser")
 
-    # VÆGTNING
-    vægtning = {}
-    for row in oversigtSoup.find("div", {"id": "s_m_Content_Content_karakterView_LectioDetailIsland1_pa"}).find_all("tr")[1:]:
-        vægtning[row.find_all("td")[1].text.replace("SAM", "Samlet vurdering")] = row.find("div", {"class": "textCenter"}).get("title").split("\n")[2].split(": ")[1] # Håber det er standardized på alle skoler
-
     karaktermeddelelse = karakterbladSoup.find("div", {"id": "s_m_Content_Content_karaktermeddelseIsland_pa"}).find_all("table")
 
     # INFORMATIONER
@@ -141,15 +183,25 @@ def karakterer(self):
     # KARAKTERER
     rows = karaktermeddelelse[1].find_all("tr")
     headers = [header.text.lower() for header in rows[0].find_all("th")]
+    karakterSum = 0
+    vægtningSum = 0
     for row in rows[2:]:
         td = row.find_all("td")
         karakter = dict([(headers[i], td[i].text.strip()) for i in range(len(td))])
         karakter["vægtning"] = vægtning[f"{karakter['fag']}{' ' + karakter['niveau'] if karakter['niveau'] != '-' else ''}, {karakter['evalueringsform']}"] # Håber det er standardized på alle skoler
         karaktererDict["karakterblad"].append(karakter)
 
+        karakterSum += float(karakter["karakter"]) * float(karakter["vægtning"].replace(",", "."))
+        vægtningSum += float(karakter["vægtning"].replace(",", "."))
+
+    karaktererDict["oversigt"]["karakterblad"]["gennemsnit"] = karakterSum/vægtningSum
+    karaktererDict["oversigt"]["karakterblad"]["karakterer"] = len(rows[2:])
+
     # PROTOKOLLINJER
     rows = oversigtSoup.find("div", {"id": "printareaprotocolgrades"}).find_all("tr")
     headers = [header.text.lower().replace(" ", "_").replace("\xad", "") for header in rows[0].find_all("th")]
+    karakterSum = 0
+    vægtningSum = 0
     for row in rows[1:]:
         td = row.find_all("td")
         karakter = {}
@@ -161,6 +213,11 @@ def karakterer(self):
                 karakter[headers[i]] = td[i].text
 
         karaktererDict["protokollinjer"].append(karakter)
+        karakterSum += float(karakter["karakter"]) * float(karakter["vægt"].replace(",", "."))
+        vægtningSum += float(karakter["vægt"].replace(",", "."))
+
+    karaktererDict["oversigt"]["protokollinjer"]["gennemsnit"] = karakterSum/vægtningSum
+    karaktererDict["oversigt"]["protokollinjer"]["karakterer"] = len(rows[1:])
 
     # KARAKTERNOTER
     rows = oversigtSoup.find("div", {"id": "s_m_Content_Content_karakterView_LectioDetailIsland2_pa"}).find_all("tr")
